#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/totem/3.2/totem-3.2.2.tar.xz
#
# maintainer: (package seek a maintainers)
#

#------------------ Set Some Variables

soft='totem'
softversion='3.0.1'
arch="i486"
cpu="i686"
packageversion="72.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.*"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# ----------------- Extract sources and get ready to build
cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --localstatedir=/var \
  --disable-static \
  --enable-nautilus=no \
  --enable-introspection=no \
  --disable-schemas-compile \
  --with-html-dir=/usr/doc/$soft-$softversion \
  --disable-scrollkeeper

make -j2
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*.?

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING INSTALL license_change NEWS README TODO \
  $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/totem html )

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler-------------------------------------------------------|
totem: totem - a movie player that uses the gstreamer backend
totem:
totem: Totem is the official movie player of the GNOME desktop environment.
totem: This package is build using the gstreamer backend. Totem features a
totem: playlist, a full-screen mode, seek and volume controls, as well as
totem: keyboard navigation. It also provides thumbnailer functionality to
totem: file managers like nautilus.
totem:
totem:
totem:
totem:
EODESC

cat << "DOINST" > $dest/install/doinst.sh
# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi

# update glib schemas
if [ -x usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas 1> /dev/null 2> /dev/null
fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
